==> react-native-dl-bmkit-1.0.28.tgz: package/javascript/modules/Form/datePickerItem.tsx <==
/**
*  时间 选择项
*/

import dayjs from 'dayjs';
import React, { useMemo, useState } from 'react';
import { Text, TextStyle, TouchableOpacity, View, ViewStyle } from 'react-native';
import DateTimePickerModal from "react-native-modal-datetime-picker";
import { FormProps } from '../../kit';
import Icon from '../icon';



interface Props extends FormProps {

    /**
    *  样式
    */
    style?: ViewStyle,

    /**
    *  左侧文字
    */
    labelText?: string,
    /**
    *  左侧文字样式
    */
    labelTextStyle?: TextStyle,

	/**
	*  选中的数据 
	*/
    value?: string;

	/**
	*  显示文本的样式
	*/
    valueStyle?: TextStyle;

	/**
	*  占位符
	*/
    placeholder?: string;

    /**
    *  模式 date:年月日  dateTime:月日时分 time:时分
    */
    mode: 'date' | 'datetime' | 'time'

    /**
    *  最小可选
    */
    minDate?: string

    /**
    *  最大可选时间
    */
    maxDate?: string

    /**
    *  时间格式 YYY-MM-DD 
    */
    format?: string

    /**
    *  选择事件
    */
    onSelect?: (value: string) => void;


}

export default function DatePickerItem(props: Readonly<Props>) {
    const myFormat = props.format || (props.mode == 'date' ? 'YYYY-MM-DD' : (props.mode == 'datetime' ? 'YYYY-MM-DD HH:mm' : 'HH:mm'))
    const [isDatePickerVisible, setDatePickerVisibility] = useState(false);

    const [result, setResult] = useState(props.value)
    const [empty, setEmpty] = useState(false)


    useMemo(() => {
        setResult(props.value)
        setEmpty(false)
    }, [props.value])

    props.getFormRef && props.getFormRef((action) => {
        switch (action) {
            case 'data':
                return result;

            case 'enpty':
                setEmpty(true)
                break;
        }
    })

    return (
        <TouchableOpacity style={{ height: 55, flexDirection: 'row', alignItems: 'center', paddingHorizontal: 15, ...props.style }}
            activeOpacity={1}
            onPress={() => setDatePickerVisibility(true)}>
            <View style={{ minWidth: 80, overflow: 'hidden', flexDirection: 'row', alignItems: 'center' }}>
                {
                    props.labelText && <Text style={{ color: 'rgba(0,0,0,0.6)', fontSize: 16, ...props.labelTextStyle }} numberOfLines={1}>{props.labelText} <Text style={{ color: '#D5544F' }}>{props.require ? ' *' : ''}</Text></Text>
                }
            </View>
            <DateTimePickerModal
                isVisible={isDatePickerVisible}
                customCancelButtonIOS={() => null}
                confirmTextIOS='确定'
                date={dayjs(result).isValid() ? dayjs(result).toDate() : undefined}
                headerTextIOS={props.labelText || '选择时间'}
                mode={props.mode}
                minimumDate={dayjs(props.minDate).isValid() ? dayjs(props.minDate).toDate() : undefined}
                maximumDate={dayjs(props.maxDate).isValid() ? dayjs(props.maxDate).toDate() : undefined}
                onConfirm={(t) => {
                    setDatePickerVisibility(false)
                    let res = dayjs(t).format(myFormat)
                    setResult(res)
                    props.onSelect && props.onSelect(res)
                    setEmpty(false)
                }}
                onCancel={(t) => {
                    setDatePickerVisibility(false)
                }}
            />

            <Text style={{ flex: 1, textAlign: 'right', marginRight: 10, color: empty ? '#D5544F' : (result ? '#000' : 'rgba(0,0,0,0.3)'), fontSize: 16, ...props.labelTextStyle }}>{result ? result : (props.placeholder || '请选择')}</Text>

            <Icon iconCode={0xe649} style={{ fontSize: 10, color: 'rgba(0,0,0,0.3)', }} />
        </TouchableOpacity >
    )

}

==> react-native-dl-bmkit-1.0.30.tgz: package/javascript/modules/Form/datePickerItem.tsx <==
/**
*  时间 选择项
*/

import dayjs from 'dayjs';
import React, { useMemo, useState } from 'react';
import { Text, TextStyle, TouchableOpacity, View, ViewStyle } from 'react-native';
import DateTimePickerModal from "react-native-modal-datetime-picker";
import { FormProps } from '../../kit';
import Icon from '../icon';



interface Props extends FormProps {

    /**
    *  样式
    */
    style?: ViewStyle,

    /**
    *  左侧文字
    */
    labelText?: string,
    /**
    *  左侧文字样式
    */
    labelTextStyle?: TextStyle,

	/**
	*  选中的数据 
	*/
    value?: string;

	/**
	*  显示文本的样式
	*/
    valueStyle?: TextStyle;

	/**
	*  占位符
	*/
    placeholder?: string;

    /**
    *  模式 date:年月日  dateTime:月日时分 time:时分
    */
    mode: 'date' | 'datetime' | 'time'

    /**
    *  最小可选
    */
    minDate?: string

    /**
    *  最大可选时间
    */
    maxDate?: string

    /**
    *  时间格式 YYY-MM-DD 
    */
    format?: string

    /**
    *  选择事件
    */
    onSelect?: (value: string) => void;


}

export default function DatePickerItem(props: Readonly<Props>) {
    const myFormat = props.format || (props.mode == 'date' ? 'YYYY-MM-DD' : (props.mode == 'datetime' ? 'YYYY-MM-DD HH:mm' : 'HH:mm'))
    const [isDatePickerVisible, setDatePickerVisibility] = useState(false);

    const [result, setResult] = useState(props.value)
    const [empty, setEmpty] = useState(false)


    useMemo(() => {
        setResult(props.value)
        setEmpty(false)
    }, [props.value])

    props.getFormRef && props.getFormRef((action) => {
        switch (action) {
            case 'data':
                return result;

            case 'enpty':
                setEmpty(true)
                break;
        }
    })

    return (
        <TouchableOpacity style={{ height: 55, flexDirection: 'row', alignItems: 'center', paddingHorizontal: 15, ...props.style }}
            activeOpacity={1}
            onPress={() => setDatePickerVisibility(true)}>
            <View style={{ minWidth: 80, maxWidth: 180, overflow: 'hidden', flexDirection: 'row', alignItems: 'center' }}>
                {
                    props.labelText && <Text style={{ color: 'rgba(0,0,0,0.6)', fontSize: 16, ...props.labelTextStyle }} numberOfLines={1} ellipsizeMode='middle'>{props.labelText} <Text style={{ color: '#D5544F' }}>{props.require ? ' *' : ''}</Text></Text>
                }
            </View>
            <DateTimePickerModal
                isVisible={isDatePickerVisible}
                customCancelButtonIOS={() => null}
                confirmTextIOS='确定'
                date={dayjs(result).isValid() ? dayjs(result).toDate() : undefined}
                headerTextIOS={props.labelText || '选择时间'}
                mode={props.mode}
                minimumDate={dayjs(props.minDate).isValid() ? dayjs(props.minDate).toDate() : undefined}
                maximumDate={dayjs(props.maxDate).isValid() ? dayjs(props.maxDate).toDate() : undefined}
                onConfirm={(t) => {
                    setDatePickerVisibility(false)
                    let res = dayjs(t).format(myFormat)
                    setResult(res)
                    props.onSelect && props.onSelect(res)
                    setEmpty(false)
                }}
                onCancel={(t) => {
                    setDatePickerVisibility(false)
                }}
            />

            <Text style={{ flex: 1, textAlign: 'right', marginRight: 10, color: empty ? '#D5544F' : (result ? '#000' : 'rgba(0,0,0,0.3)'), fontSize: 16, ...props.labelTextStyle }}>{result ? result : (props.placeholder || '请选择')}</Text>

            <Icon iconCode={0xe649} style={{ fontSize: 10, color: 'rgba(0,0,0,0.3)', }} />
        </TouchableOpacity >
    )

}
